==> coventry-v0.9.2.tar.gz: coventry-v0.9.2/src/events.hpp <==
/*
 * Copyright (C) 2020 Tycho Softworks.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef EVENTS_HPP
#define EVENTS_HPP

#include "server.hpp"       // IWYU pragma: keep
#include "exosip.hpp"

#include <moderncli/sync.hpp>

namespace server {
class event_t : public exosip::event_t {
public:
    explicit event_t(const exosip::context_t &ctx, const std::string& addr) noexcept;
    event_t() noexcept;

    explicit operator eXosip_t *() const {
        return ctx_;
    }

    auto expires() const {
        if(data_->expires == data_->created)
            return sync_timepoint::max();
        return data_->expires;
    }

    void fail_message(int code, osip_message_t *msg = nullptr) const {
        log_access(code);
        const exosip::guard_t lock(context());
        eXosip_message_send_answer(context(), tid(), code, msg);
    }

    void fail_call(int code, osip_message_t *msg = nullptr) const {
        log_access(code);
        const exosip::guard_t lock(context());
        eXosip_call_send_answer(context(), tid(), code, msg);
    }

    void terminate_call() const {
        const exosip::guard_t lock(context());
        eXosip_call_terminate(context(), cid(), did());
    }

    auto created() const {return data_->created;}
    auto address() const {return data_->address;}
    auto schema() const {return data_->schema;}
    auto realm() const {return data_->realm;}
    auto user() const {return data_->user;}
    auto uri() const {return data_->uri;}
    auto authorize() const {return authorize_;}
    auto algorithm() const {return data_->algorithm;}
    auto digest() const {return data_->digest;}
    auto nonce() const {return data_->nonce;}
    auto count() const {return data_->count;}
    auto client() const {return data_->client;}
    auto qop() const {return data_->qop;}
    auto period() const {return period_;}
    auto refresh() const {return refresh_;}
    auto port() const { return port_;}
    auto from() const { return (evt_ && evt_->request) ? evt_->request->from : nullptr;}
    auto to() const { return (evt_ && evt_->request) ? evt_->request->to : nullptr;}

    auto subject() const {
        osip_header_t *header{nullptr};
        if(evt_ && evt_->request)
            osip_message_get_subject(evt_->request, 0, &header);
        return (header && header->hvalue) ? std::string_view(header->hvalue) : "";
    }

    auto publish() const {
        osip_header_t *header{nullptr};
        if(evt_ && evt_-> request)
            osip_message_header_get_byname(evt_->request, "event", 0, &header);
        return (header && header->hvalue) ? std::string_view(header->hvalue) : "";
    }

    auto agent() const {
        osip_header_t *header{nullptr};
        if(evt_ && evt_->request)
            osip_message_get_user_agent(evt_->request, 0, &header);
        return (header && header->hvalue) ? std::string_view(header->hvalue) : "";
    }

    auto body() const {
        osip_body_t *data{nullptr};
        if(evt_ && evt_->request)
            osip_message_get_body(evt_->request, 0, &data);
        return data;
    }

    auto reply() const {
        osip_body_t *data{nullptr};
        if(evt_ && evt_->response)
            osip_message_get_body(evt_->response, 0, &data);
        return data;
    }

    auto content() const -> std::string;
    auto is_expired() const -> bool;
    auto remains() const -> unsigned;
    void log_access(int code) const;
    void expires(unsigned msecs);

private:
    struct data_t final {
        sync_timepoint created, expires;
        std::string address, schema, uri;
        std::string_view realm, user, nonce, algorithm, digest, qop, client, count;
    };

    std::shared_ptr<data_t> data_;
    osip_authorization_t *authorize_{};
    time_t period_{0}, refresh_{0};
    uint16_t port_{0};
};

inline auto content_view(osip_body_t *body) {
    if(body && body->body)
        return std::string_view(body->body, body->length);
    return std::string_view();
}

void allow_local(exosip::msg_t msg);
void allow_remote(exosip::msg_t msg);
//auto content_type(osip_body_t *body) -> std::string;
auto msg_to_string(exosip::msg_t msg) -> std::string;

void exec_local(exosip::context_t& context, const keyfile& ini);
void exec_remote(exosip::context_t& context, const keyfile& ini);
} // end namespace
#endif

==> coventry-v0.9.3.tar.gz: coventry-v0.9.3/src/events.hpp <==
/*
 * Copyright (C) 2020 Tycho Softworks.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef EVENTS_HPP
#define EVENTS_HPP

#include "server.hpp"       // IWYU pragma: keep
#include "exosip.hpp"

#include <moderncli/sync.hpp>

namespace server {
class event_t final : public exosip::event_t {
public:
    explicit event_t(const exosip::context_t &ctx, const std::string& addr) noexcept;
    event_t() noexcept;

    explicit operator eXosip_t *() const {
        return ctx_;
    }

    auto expires() const {
        if(data_->expires == data_->created) return sync_timepoint::max();
        return data_->expires;
    }

    void fail_message(int code, osip_message_t *msg = nullptr) const {
        log_access(code);
        const exosip::guard_t lock(context());
        eXosip_message_send_answer(context(), tid(), code, msg);
    }

    void fail_call(int code, osip_message_t *msg = nullptr) const {
        log_access(code);
        const exosip::guard_t lock(context());
        eXosip_call_send_answer(context(), tid(), code, msg);
    }

    void terminate_call() const {
        const exosip::guard_t lock(context());
        eXosip_call_terminate(context(), cid(), did());
    }

    auto created() const {return data_->created;}
    auto address() const {return data_->address;}
    auto schema() const {return data_->schema;}
    auto realm() const {return data_->realm;}
    auto user() const {return data_->user;}
    auto uri() const {return data_->uri;}
    auto authorize() const {return authorize_;}
    auto algorithm() const {return data_->algorithm;}
    auto digest() const {return data_->digest;}
    auto nonce() const {return data_->nonce;}
    auto count() const {return data_->count;}
    auto client() const {return data_->client;}
    auto qop() const {return data_->qop;}
    auto period() const {return period_;}
    auto refresh() const {return refresh_;}
    auto port() const { return port_;}
    auto from() const { return (evt_ && evt_->request) ? evt_->request->from : nullptr;}
    auto to() const { return (evt_ && evt_->request) ? evt_->request->to : nullptr;}

    auto subject() const {
        osip_header_t *header{nullptr};
        if(evt_ && evt_->request)
            osip_message_get_subject(evt_->request, 0, &header);
        return (header && header->hvalue) ? std::string_view(header->hvalue) : "";
    }

    auto publish() const {
        osip_header_t *header{nullptr};
        if(evt_ && evt_-> request)
            osip_message_header_get_byname(evt_->request, "event", 0, &header);
        return (header && header->hvalue) ? std::string_view(header->hvalue) : "";
    }

    auto agent() const {
        osip_header_t *header{nullptr};
        if(evt_ && evt_->request)
            osip_message_get_user_agent(evt_->request, 0, &header);
        return (header && header->hvalue) ? std::string_view(header->hvalue) : "";
    }

    auto body() const {
        osip_body_t *data{nullptr};
        if(evt_ && evt_->request)
            osip_message_get_body(evt_->request, 0, &data);
        return data;
    }

    auto reply() const {
        osip_body_t *data{nullptr};
        if(evt_ && evt_->response)
            osip_message_get_body(evt_->response, 0, &data);
        return data;
    }

    auto content() const -> std::string;
    auto is_expired() const -> bool;
    auto remains() const -> unsigned;
    void log_access(int code) const;
    void expires(unsigned msecs);

private:
    struct data_t final {
        sync_timepoint created, expires;
        std::string address, schema, uri;
        std::string_view realm, user, nonce, algorithm, digest, qop, client, count;
    };

    std::shared_ptr<data_t> data_;
    osip_authorization_t *authorize_{};
    time_t period_{0}, refresh_{0};
    uint16_t port_{0};
};

inline auto content_view(osip_body_t *body) {
    if(body && body->body) return std::string_view(body->body, body->length);
    return std::string_view();
}

void allow_local(exosip::msg_t msg);
void allow_remote(exosip::msg_t msg);
//auto content_type(osip_body_t *body) -> std::string;
auto msg_to_string(exosip::msg_t msg) -> std::string;

void exec_local(exosip::context_t& context, const keyfile& ini);
void exec_remote(exosip::context_t& context, const keyfile& ini);
} // end namespace
#endif
